===============================
``pyramid_oereb`` (ÖREB-Server)
===============================

|Build Status|

``pyramid_oereb`` is an open-source implementation of the server side part for the swiss `"Cadastre of
Public-law Restrictions on landownership" (PLR-cadastre) <https://www.cadastre.ch/en/oereb.html>`__.

It is written in Python and designed as a plugin for the `Pyramid Web Framework
<http://docs.pylonsproject.org/projects/pyramid/en/latest/>`__. This allows *pyramid\_oereb* to be included in
any Pyramid web application.

Please refer to the `documentation <https://camptocamp.github.io/pyramid_oereb/doc/>`__ for detailed
information and instructions for installation and configuration.

If you are interested in contributing or extending the project, take a look at the
`contribution page <https://camptocamp.github.io/pyramid_oereb/doc/master/contrib/>`__.

.. |Build Status| image:: https://travis-ci.com/camptocamp/pyramid_oereb.svg?token=oTUZsPVUPe1BYV5bzANE&branch=master
   :target: https://travis-ci.com/camptocamp/pyramid_oereb
